import { NextObserver, Observable, Subscribable } from 'rxjs';
import { MessageTransports } from '../connections/jsonrpc2';
import { ApolloClient, ApolloQueryResult } from '@apollo/client/index.js';
/**
 * Platform-specific data and methods shared by multiple Cdeops components.
 *
 * Whenever api code needs to perform an action or retrieve data that requires different
 * implementations depending on the platform, the api code should use this value's fields.
 */
export interface IPlatformContext {
    /**
     * Graphql context
     */
    apolloClient: ApolloClient<any>;
    /**
     * Redux observable state
     */
    reduxState$: Observable<any>;
    /**
     * An observable that emits the settings cascade upon subscription and whenever it changes (including when it
     * changes as a result of a call to {@link PlatformContext#updateSettings}).
     *
     * It should be a cold observable so that it does not trigger a network request upon each subscription.
     */
    readonly settings: Observable<any>;
    /**
     * Sends a request to the Cdeops Graphql API and returns the response.
     *
     * @template R The GraphQL result type
     * @param request The GraphQL request (query or mutation)
     * @param variables An object whose properties are GraphQL query name-value variable pairs
     * @param mightContainPrivateInfo 🚨 SECURITY: Wehther or not sending the GraphQL request to backend gateway.
     * @return Observable that emits the result or an error if the HTTP request failed
     */
    requestGraphQL<R, V = object>(request: string, variables: V, mightContainPrivateInfo: boolean): Observable<ApolloQueryResult<R>>;
    /**
     * Spawns a new JavaScript execution context (such as a Web Worker or browser extension backgroudn worker)
     * with the extension host and opens a communciation channel to it. It is
     * called exactly once, to start the extension host.
     *
     * @returns An observable that emits at most once with the message transports for communicating
     * with the execution context (using, e.g., postMessage/onmessage) when it is ready.
     */
    createExtensionHost(): Observable<MessageTransports>;
    /**
     * Returns the script URL suitable for passing to importScripts for an extension's bundle.
     *
     * This is necessary because some platforms (such as Chrome extensions) use a script-src CSP
     * that would prevent loading bundles from arbitrary URLs, which requires us to pass blob: URIs
     * to importScripts.
     *
     * @param bundleURL The URL to the JavaScript bundle file specified in the extension manifest.
     * @return A script URL suitable for passing to importScripts, typically either the original
     * https:// URL for the extenion's bundle or a blob: URI for it.
     */
    getScriptURLForExtension(bundleURL: string): string | Promise<string>;
    /**
     * The URL to the Cdeops site that the user's session is associated with. This refers to
     * Cdeops.com (`https://cdeops.com`) by default, or a self-hosted instance of Cdeops.
     *
     * This is available to extensions in `cdeops.internal.cdeopsURL`.
     *
     * @example `https://cdeops.com`
     */
    cdeopsURL: string;
    /**
     * The client application that is running this extension, either `cdeops` for IDE
     * or 'other' for all other applciations.
     *
     * This is avaialble to extensions in `cdeops.internal.clientApplication`.
     */
    clientApplication: 'cdeops' | 'other';
    /**
     * The URL to the Parcel dev server for a single extension.
     * Used for extension development purposes, to run an extension that isn't on the registry.
     */
    sideloadedExtensionURL: Subscribable<string | null> & NextObserver<string | null>;
    /**
     * Whether to log all messages sent between the client and the extensionhost.
     */
    traceExtensionHostCommunication: Subscribable<boolean> & NextObserver<boolean>;
}
